@@ -2,8 +2,10 @@ __all__ = [
     "analyze_latent",
     "encode_data",
     "identify_associations",
+    "tune_model",
 ]
 
 from move.tasks.analyze_latent import analyze_latent
 from move.tasks.encode_data import encode_data
 from move.tasks.identify_associations import identify_associations
+from move.tasks.tune_model import tune_model
